@@ -567,8 +567,8 @@ class ModelInterface(ABC):
         self,
         chats: Thread | str,
         model: str | None = None,
-        max_tokens: int = None,
-        temperature: float = 1,
+        max_tokens: int | None = None,
+        temperature: float | None = None,
         token: str | None = None,
         usage: bool = False,
         extra_headers: dict[str, str] | None = None,
@@ -585,8 +585,8 @@ class ModelInterface(ABC):
         self,
         chats: Thread | str,
         model: str | None = None,
-        max_tokens: int = None,
-        temperature: float = 1,
+        max_tokens: int | None = None,
+        temperature: float | None = None,
         parallel_tool_calls: bool = False,
         token: str | None = None,
         usage: bool = False,
@@ -603,8 +603,8 @@ class ModelInterface(ABC):
         self,
         chats: Thread | str,
         model: str | None = None,
-        max_tokens: int = None,
-        temperature: float = 1,
+        max_tokens: int | None = None,
+        temperature: float | None = None,
         token: str | None = None,
         usage: bool = False,
         extra_headers: dict[str, str] | None = None,
@@ -621,8 +621,8 @@ class ModelInterface(ABC):
         self,
         chats: Thread | str,
         model: str | None = None,
-        max_tokens: int = None,
-        temperature: float = 1,
+        max_tokens: int | None = None,
+        temperature: float | None = None,
         parallel_tool_calls: bool = False,
         token: str | None = None,
         usage: bool = False,
@@ -638,7 +638,7 @@ class ModelInterface(ABC):
     def distributed_chat(
         self,
         prompts: list[Thread],
-        post_logic: Callable | None = None,
+        post_logic: Optional[callable] = None,
         max_threads: int = 10,
         retry: int = 3,
         pbar=True,
@@ -652,7 +652,7 @@ class ModelInterface(ABC):
     async def distributed_chat_async(
         self,
         prompts: list[Thread],
-        post_logic: Callable | None = None,
+        post_logic: Optional[callable] = None,
         max_threads: int = 10,
         retry: int = 3,
         pbar=True,
@@ -778,12 +778,12 @@ class ModelInterface(ABC):
         self,
         threads: list[Thread | str],
         model: str | None = None,
-        max_tokens: int = 4096,
+        max_tokens: int | None = None,
         temperature: float | None = None,
         token: str | None = None,
         debug: bool = False,
         extra_headers: dict[str, str] | None = None,
-        timeout=(5, 30),
+        timeout: tuple[int, int] = (5, 60),
         raw: bool = False,
         **kwargs,
     ) -> tuple[str, list[str]] | dict:
